# libpython
Modulo para exemplificar a construção de projetos python pro
Suportado a versão 10 em python

[![Build Status](https://app.travis-ci.com/cyaconquista/libpython.svg?branch=main)](https://app.travis-ci.com/cyaconquista/libpython)
Link Py UP
https://pyup.io/account/repos/github/cyaconquista/libpython/
Para instalar:
'''
py -3 -m venv .venv
.venv\Scripts\activate
pip install - r requirements-dev.txt

'''console
flake8
'''

